@@ -14,4 +14,4 @@ sudo apt-get -q install -y adoptopenjdk-8-hotspot-jre=8u232-b09-2
 
 curl -L -s -S https://d24mnm5myvorwj.cloudfront.net/documents/download/neoload/v7.7/loadGenerator_7_7_0_linux_x64.tar.gz > loadGenerator_7_7_0_linux_x64.tar.gz
 tar zxf loadGenerator_7_7_0_linux_x64.tar.gz
-cp nlAgent/agent.properties ~/neoload7.7/conf
+cp nlAgent/*.properties ~/neoload7.7/conf
